@@ -5,6 +5,11 @@
 More detailed description.
 """
 
-__version__ = '1.3.13'
+__version__ = '1.3.14'
 __author__ = 'Benjamin Pillot'
 __email__ = 'benjaminpillot@riseup.net'
+
+
+import gdal
+
+GDAL_DEFAULT_DRIVER = gdal.GetDriverByName("Gtiff")
